Balsam MPI Executor
===================

.. automodule:: balsam_executor
  :no-undoc-members:

.. autoclass:: BalsamMPIExecutor
  :show-inheritance:
..  :inherited-members:
..  :member-order: bysource
..  :members: __init__, submit, poll, manager_poll, kill, set_kill_mode

.. autoclass:: BalsamTask
  :show-inheritance:
  :member-order: bysource
..  :members: workdir_exists, file_exists_in_workdir, read_file_in_workdir, stdout_exists, read_stdout
..  :inherited-members:
